
SoundManager = function(game)
{
    this.game = game;
    try{
        this.soundPlaying = SOUNDS_ENABLED;
        this.musicPlaying = SOUNDS_ENABLED;

        if(getProfileVar("snd") != null)
            this.soundPlaying = SOUNDS_ENABLED && (getProfileVar("snd") === true);
        if(getProfileVar("msc") != null)
            this.musicPlaying = SOUNDS_ENABLED && (getProfileVar("msc") === true);
    }catch(e){
        this.soundPlaying = SOUNDS_ENABLED;
        this.musicPlaying = SOUNDS_ENABLED;
    }

    if(GameData.BuildDebug){
        this.musicPlaying = false;
        this.soundPlaying = false;
    }

    this.music = [];
    this.sounds = [];
    this.actualMusic = null;
    this.prevSoundPlayed = null;
}

SoundManager.prototype = {
    constructor: SoundManager,

    create: function ()
    {
        this.addMusic('music_menu', 0.6, true);

        this.addSound('card', 0.2);
        this.addSound('coins', 0.2);
        this.addSound('claim', 0.2);
        this.addSound('redeal', 0.4);
        this.addSound('nomove', 0.2);
        this.addSound('jingle_win', 0.4);
        this.addSound('achieve', 0.4);

        this.addSound('harph0', 0.4);
        this.addSound('harph1', 0.4);
        this.addSound('harph2', 0.4);
        this.addSound('harph3', 0.4);

        this.addSound('dialog', 0.4);
        this.addSound('undo', 0.4);
        this.addSound('lose', 0.4);

        this.addSound('tile_wrong-one', 0.4);
        this.addSound('menu-click1', 0.4);
        this.addSound('result_bronze-silver-star', 0.4);
        this.addSound('result_gold-star', 0.4);

        game.input.onDown.addOnce(function () {
            if(soundManager.musicPlaying) {
                try {
                    game.sound.context.resume();
                } catch (e) {}
            }
        });
    },

    addMusic: function(audioFile, volume, loop)
    {
        if ( loop === undefined )
            loop = false;

        this.music[audioFile] = game.add.audio(audioFile, volume, loop);
    },

    addSound: function(audioFile, volume, loop)
    {
        if ( loop === undefined )
            loop = false;

        this.sounds[audioFile] = game.add.audio(audioFile, volume, loop);
    },

    playMusic: function (musicToPlay, reset)
    {
        if ( reset === undefined )
            reset = false;


        if (musicToPlay != this.actualMusic || reset)
            this.actualMusic = musicToPlay;

        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].play();
            else
                this.music[key].stop();
        }

        try {
            game.sound.context.resume();
        } catch (e) {}
    },

    playSound: function (soundToPlay)
    {
        if(!this.soundPlaying)
            return;

        try{
            this.sounds[soundToPlay].play();
        }catch(e){
            LOG('Failed to play sound : ' + soundToPlay);
        }

        try {
            game.sound.context.resume();
        } catch (e) {}
    },

    pauseMusic: function()
    {
        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].pause();
        }
    },

    resumeMusic: function()
    {
        if (!this.musicPlaying)
            return;

        for (var key in this.music){
            if(key == 'contains')
                continue;
            if (key == this.actualMusic)
                this.music[key].resume();
        }

        try {
            game.sound.context.resume();
        } catch (e) {}
    },

    stopMusic: function ()
    {
        for (var key in this.music){
            if(key == 'contains')
                continue;

            this.music[key].stop();
        }
    },

    toggleMusic: function(musicToPlay)
    {
        if (!this.musicPlaying){
            this.musicPlaying = true;
            this.playMusic(musicToPlay);
        } else {
            this.musicPlaying = false;
            this.stopMusic();
        }

        GameData.Save();
    },

    toggleSounds: function()
    {
        if (!this.soundPlaying)
            this.soundPlaying = true;
        else{
            this.soundPlaying = false;

            for (var key in this.sounds){
                if(key == 'contains')
                    continue;

                this.sounds[key].stop();
            }
        }

        GameData.Save();
    }
}